@@ -3,6 +3,8 @@ import json
 import os
 from logging import getLogger
 
+from dotenv import load_dotenv
+
 from commanderbot.core.commander_bot import CommanderBot
 from commanderbot.lib.logging import setup_logging
 
@@ -20,6 +22,11 @@ def run():
         "--tokenfile",
         help="Bot token file (prefer using the BOT_TOKEN environment variable)",
     )
+    arg_parser.add_argument(
+        "--envfile",
+        help="The .env file to load environment variables from (defaults to .env)",
+        default=".env",
+    )
     arg_parser.add_argument("--log", help="Log level", default="WARNING")
     parsed_args = arg_parser.parse_args()
 
@@ -40,6 +47,9 @@ def run():
 
     log.info(f"Number of configuration keys: {len(config)}")
 
+    envfile = parsed_args.envfile
+    load_dotenv(envfile)
+
     bot_token = os.environ.get("BOT_TOKEN", None)
 
     if not bot_token:
