@@ -10,11 +10,11 @@ def check_commander_bot(bot: Bot) -> Optional[CommanderBotBase]:
         return bot
 
 
-def add_configured_cog(bot: Bot, ext_name: str, cog_class: Type[Cog]):
+async def add_configured_cog(bot: Bot, ext_name: str, cog_class: Type[Cog]):
     cog = None
     if cb := check_commander_bot(bot):
         if options := cb.get_extension_options(ext_name):
             cog = cog_class(bot, **options)
     if not cog:
         cog = cog_class(bot)
-    bot.add_cog(cog)
+    await bot.add_cog(cog)
