@@ -4,5 +4,5 @@ from commanderbot.ext.automod.automod_cog import AutomodCog
 from commanderbot.core.utils import add_configured_cog
 
 
-def setup(bot: Bot):
-    add_configured_cog(bot, __name__, AutomodCog)
+async def setup(bot: Bot):
+    await add_configured_cog(bot, __name__, AutomodCog)
