@@ -16,7 +16,7 @@ ST = TypeVar("ST")
 @dataclass
 class ActorIsNotBot(TargetIsNotBotBase):
     """
-    Check if the actor in context is not a bot.
+    Check if the actor in context is *not* a bot.
     """
 
     def get_target(self, event: AutomodEvent) -> Optional[Member]:
