@@ -4,5 +4,5 @@ from commanderbot.ext.faq.faq_cog import FaqCog
 from commanderbot.core.utils import add_configured_cog
 
 
-def setup(bot: Bot):
-    add_configured_cog(bot, __name__, FaqCog)
+async def setup(bot: Bot):
+    await add_configured_cog(bot, __name__, FaqCog)
