@@ -4,5 +4,5 @@ from commanderbot.core.utils import add_configured_cog
 from commanderbot.ext.jira.jira_cog import JiraCog
 
 
-def setup(bot: Bot):
-    add_configured_cog(bot, __name__, JiraCog)
+async def setup(bot: Bot):
+    await add_configured_cog(bot, __name__, JiraCog)
