@@ -1,6 +1,7 @@
 from typing import Any
 
 import discord
+from discord.mentions import default
 
 from commanderbot.lib.from_data_mixin import FromDataMixin
 from commanderbot.lib.json_serializable import JsonSerializable
@@ -13,11 +14,11 @@ class AllowedMentions(JsonSerializable, discord.AllowedMentions, FromDataMixin):
 
     @classmethod
     def not_everyone(cls):
-        return cls(everyone=False, users=True, roles=True, replied_user=True)
+        return cls(everyone=False)
 
     @classmethod
     def only_replies(cls):
-        return cls(everyone=False, users=False, roles=False, replied_user=True)
+        return cls(everyone=False, users=False, roles=False)
 
     # @overrides FromDataMixin
     @classmethod
@@ -30,9 +31,9 @@ class AllowedMentions(JsonSerializable, discord.AllowedMentions, FromDataMixin):
 
     # @implements JsonSerializable
     def to_json(self) -> Any:
-        return dict(
-            everyone=self.everyone,
-            users=self.users,
-            roles=self.roles,
-            replied_user=self.replied_user,
-        )
+        fields = ("everyone", "users", "roles", "replied_user")
+        data = {}
+        for field in fields:
+            if (value := getattr(self, field, default)) is not default:
+                data[field] = value
+        return data
