@@ -1,5 +1,6 @@
+import difflib
 import re
-from typing import List
+from typing import List, Tuple
 
 from discord import Role
 from discord.ext.commands import BadArgument, RoleConverter, RoleNotFound
@@ -9,7 +10,6 @@ from commanderbot.lib.types import GuildContext
 __all__ = (
     "CannotDisambiguateRole",
     "LenientRoleConverter",
-    "LenientRole",
 )
 
 
@@ -34,10 +34,6 @@ class LenientRoleConverter(RoleConverter):
     """
 
     async def convert(self, ctx: GuildContext, argument: str) -> Role:
-        # Use regex to do a partial match, with the input escaped.
-        escaped = re.escape(argument)
-        pattern = re.compile(f"\\b{escaped}\\b", re.IGNORECASE)
-
         # Attempt to look-up the role as usual.
         try:
             if role := await super().convert(ctx, argument):
@@ -47,16 +43,29 @@ class LenientRoleConverter(RoleConverter):
         except RoleNotFound:
             pass
 
-        # If nothing was found, proceed to use a more lenient approach.
-        roles = self.filter_roles(ctx, argument, pattern)
+        # If nothing was found, use a more lenient approach...
+
+        # Use regex to do a partial match, with the input escaped.
+        escaped = re.escape(argument)
+        pattern = re.compile(f"\\b{escaped}\\b", re.IGNORECASE)
+        matches = self.filter_roles(ctx, argument, pattern)
 
         # If exactly one role was found, return it.
-        if len(roles) == 1:
-            return roles[0]
+        if len(matches) == 1:
+            return matches[0]
 
-        # If multiple roles were found, raise.
-        if len(roles) > 1:
-            raise CannotDisambiguateRole(argument, roles)
+        # If multiple roles were found, use difflib to grab the best match.
+        if len(matches) > 1:
+            rated_matches = self.rate_matches(argument, matches)
+            first_place = rated_matches[0]
+            second_place = rated_matches[1]
+
+            # If there's exactly 1 best match, return it.
+            if first_place[0] > second_place[0]:
+                return first_place[1]
+
+            # Otherwise, we cannot disambiguate.
+            raise CannotDisambiguateRole(argument, matches)
 
         # If still nothing was found, raise.
         raise RoleNotFound(argument)
@@ -64,7 +73,7 @@ class LenientRoleConverter(RoleConverter):
     def filter_roles(
         self, ctx: GuildContext, argument: str, pattern: re.Pattern
     ) -> List[Role]:
-        roles = ctx.guild.roles
+        roles = list(ctx.guild.roles)
         roles.remove(ctx.guild.default_role)
         return [role for role in roles if self.match_role(ctx, argument, pattern, role)]
 
@@ -74,6 +83,13 @@ class LenientRoleConverter(RoleConverter):
         match = pattern.search(role.name)
         return match is not None
 
-
-class LenientRole(LenientRoleConverter, Role):
-    pass
+    def rate_matches(
+        self, argument: str, matches: List[Role]
+    ) -> List[Tuple[float, Role]]:
+        return sorted(
+            [
+                (difflib.SequenceMatcher(None, argument, role.name).ratio(), role)
+                for role in matches
+            ],
+            reverse=True,
+        )
