@@ -3,6 +3,7 @@ from typing import Any, Iterable, Tuple
 
 from discord import Member
 
+from commanderbot.lib.utils import utcnow_aware
 from commanderbot.lib.value_formatter import ValueFormatter
 
 
@@ -18,7 +19,7 @@ def yield_member_date_fields(prefix: str, member: Member) -> Iterable[Tuple[str,
     yield f"{prefix}_joined_at", joined_at_value
 
     # member_for
-    now = datetime.utcnow().replace(tzinfo=timezone.utc)
+    now = utcnow_aware()
     if isinstance(joined_at, datetime):
         member_for = now - joined_at
         member_for_str = f"{member_for.days} days"
